@@ -3,6 +3,7 @@ import logging
 import os
 import pathlib
 from irisml.azureml import AMLJobManager, Job, JobEnvironment
+from irisml.core.commands.common import configure_logger
 
 logger = logging.getLogger(__name__)
 
@@ -15,6 +16,8 @@ def main():
             d = getattr(namespace, self.dest)
             d[k] = v
 
+    configure_logger()
+
     parser = argparse.ArgumentParser()
     parser.add_argument('job_filepath', type=pathlib.Path)
     parser.add_argument('--env', '-e', nargs=1, default={}, action=KeyValuePairAction)
@@ -31,6 +34,7 @@ def main():
     parser.add_argument('--experiment', default=os.getenv('IRISML_AML_EXPERIMENT_NAME', 'irisml'))
     parser.add_argument('--base_docker_image')
     parser.add_argument('--base_docker_image_registry')
+    parser.add_argument('--use_sp_on_remote', '--sp', action='store_true', help="Use Service Principal id and secret on the AML job.")
 
     args = parser.parse_args()
 
@@ -51,7 +55,7 @@ def main():
     env = JobEnvironment(args.base_docker_image, args.base_docker_image_registry, custom_packages, args.extra_index_url)
     print(env)
 
-    job_manager = AMLJobManager(args.subscription_id, args.workspace, args.experiment, args.compute_target)
+    job_manager = AMLJobManager(args.subscription_id, args.workspace, args.experiment, args.compute_target, use_sp_on_remote=args.use_sp_on_remote)
     run = job_manager.submit(job, env)
     print(run)
 
